@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright 2023 Observational Health Data Sciences and Informatics
+ * Copyright 2025 Observational Health Data Sciences and Informatics
  * 
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -21,14 +21,24 @@ package org.ohdsi.data;
 public class SortedCoxData {
 
     public int[] y;
-    public double[] x;
+    public double[] x; // Assumes row-major
     public int[] strata;
+    public int[] n;
     public double[] weight;
 
     public SortedCoxData(int[] y, double[] x, int[] strata, double[] weight) {
+        this(y, x, strata, null, weight);
+    }
+
+    public SortedCoxData(int[] y, double[] x, int[] strata, int[] n, double[] weight) {
         this.y = y;
         this.x = x;
         this.strata = strata;
+        this.n = n;
         this.weight = weight;
     }
+
+    public int getCovariateDimension() {
+        return x.length / y.length;
+    }
 }
