@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright 2023 Observational Health Data Sciences and Informatics
+ * Copyright 2025 Observational Health Data Sciences and Informatics
  * 
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,16 +15,21 @@
  ******************************************************************************/
 package org.ohdsi.likelihood;
 
-import dr.inference.model.*;
-
 import org.apache.commons.math.util.FastMath;
 import org.ohdsi.data.SortedCoxData;
 
+import dr.inference.model.AbstractModelLikelihood;
+import dr.inference.model.Likelihood;
+import dr.inference.model.Model;
+import dr.inference.model.Parameter;
+import dr.inference.model.Variable;
+
 /**
  * @author Marc A. Suchard
  */
 public class CoxPartialLikelihood extends AbstractModelLikelihood {
 
+	private static final long serialVersionUID = 5671381056989317642L;
 	private final Parameter beta;
 	private final SortedCoxData data;
 	private final int N;
@@ -44,7 +49,7 @@ public class CoxPartialLikelihood extends AbstractModelLikelihood {
 
 		double sum = 0.0;
 		for (int i = 0; i < N; ++i) {
-			sum += (y[i] == 1) ? x[i] : 0.0;
+			sum += y[i] * x[i];
 		}
 		numeratorConstant = sum;
 	}
@@ -55,8 +60,9 @@ public class CoxPartialLikelihood extends AbstractModelLikelihood {
 
 	private double denominatorContribution() {
 
-		final double[] weight = data.weight;
+		final int[] n = data.n;
 		final double[] x = data.x;
+		final int[] y = data.y;
 		final int[] strata = data.strata;
 		final double b = beta.getParameterValue(0);
 
@@ -70,10 +76,7 @@ public class CoxPartialLikelihood extends AbstractModelLikelihood {
 				++resetIndex;
 			}
 			denominatorTotal += FastMath.exp(x[i] * b);
-			double increment =  weight[i] * FastMath.log(denominatorTotal);
-			sum += increment;
-
-			//            System.err.println("\t\t" + i + " " + denominatorTotal + ":" + increment);
+			sum += n[i] * FastMath.log(denominatorTotal);
 		}
 
 		return sum;
@@ -86,6 +89,7 @@ public class CoxPartialLikelihood extends AbstractModelLikelihood {
 	@Override
 	protected void handleModelChangedEvent(Model model, Object o, int i) { }
 
+	@SuppressWarnings("rawtypes")
 	@Override
 	protected void handleVariableChangedEvent(Variable variable, int i, Variable.ChangeType changeType) {
 		if (variable == beta) {
@@ -137,26 +141,27 @@ public class CoxPartialLikelihood extends AbstractModelLikelihood {
 
 	public static void main(String[] args) {
 
-		// No strata
-		//   		int[] y = new int[] { 1, 1, 0, 1, 1, 0, 1 };
-		//   		double[] x = new double[] { 0, 2, 0, 0, 1, 1, 1 };
-		//   		int[] strata = new int[] { 7 };
-		//   		double beta = 0.3883064;
+		int[] y;
+		double[] x;
+		int[] yTimesTieCount;
+		int[] strata;
+		double beta;
 
-		// With strata
-		int[] y = new int[] { 1, 1, 0, 1, 0, 1, 1 };
-		double[] weight = new double[] { 1, 1, 0, 1, 0, 1, 1 };
-		double[] x = new double[] { 0, 2, 1, 1, 0, 0, 1 };
-		int[] strata = new int[] { 4, 7 };
-		double beta = 1.205852;
-		// logLike = -2.978028
+		SortedCoxData data;
+		Parameter parameter;
+		Likelihood cox;
 
-		SortedCoxData data = new SortedCoxData(y, x, strata, weight);
+		// No ties, no strata, no weights
+		y = new int[] { 1, 1, 0, 1, 1, 0, 1 };
+		x = new double[] { 0, 2, 0, 0, 1, 1, 1 };
+		yTimesTieCount = new int[] { 1, 1, 0, 1, 1, 0, 1 };
+		strata = new int[] { 7 };
+		beta = 0.3883064;
+		// logLik = -5.401371
 
-		Parameter parameter = new Parameter.Default(beta);
-
-		Likelihood cox = new CoxPartialLikelihood(parameter, data);
-
-		System.err.println(cox.getLogLikelihood());
+		data = new SortedCoxData(y, x, strata, yTimesTieCount, null);
+		parameter = new Parameter.Default(beta);
+		cox = new CoxPartialLikelihood(parameter, data);
+		System.err.println("C " + cox.getLogLikelihood());
 	}
 }
