@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright 2023 Observational Health Data Sciences and Informatics
+ * Copyright 2025 Observational Health Data Sciences and Informatics
  * 
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -43,21 +43,25 @@ public class Runner {
 	final int subSampleFrequency;
 	int consoleWidth = 175;
 
-	public Runner(Analysis analysis, int chainLength, int burnIn, int subSampleFrequency, double seed) {
+	public Runner(Analysis analysis, int chainLength, int burnIn, int subSampleFrequency, double seed, boolean showProgressBar) {
 
 		// Set seed
 		MathUtils.setSeed(Math.round(seed));
 
 		this.joint = analysis.getJoint();
 		this.schedule = analysis.getSchedule();
-		this.logger = getLogger(analysis.getLoggerColumns(), subSampleFrequency);
+		this.logger = getLogger(analysis.getLoggerColumns(), subSampleFrequency, showProgressBar);
 
 		this.chainLength = chainLength;
 		this.burnIn = burnIn;
 		this.subSampleFrequency = subSampleFrequency;
 	}
 
-	private Logger[] getLogger(List<Loggable> columns, int subSampleFrequency) {
+	public Runner(Analysis analysis, int chainLength, int burnIn, int subSampleFrequency, double seed) {
+		this(analysis, chainLength, burnIn, subSampleFrequency, seed, true);
+	}
+
+	private Logger[] getLogger(List<Loggable> columns, int subSampleFrequency, boolean showProgressBar) {
 
 		ArrayLogFormatter formatter = new ArrayLogFormatter(false);
 
@@ -83,7 +87,7 @@ public class Runner {
 
 			@Override
 			public void log(long iteration) {
-				if (iteration % 10000 == 0) {
+				if (iteration % 10000 == 0 && showProgressBar) {
 					progressPercentage(iteration, chainLength);
 				}
 			}
@@ -166,9 +170,9 @@ public class Runner {
 		boolean useAdaptation = true;
 		long adaptationDelay = chainLength / 100;
 		double adaptationTarget = 0.234;
-		boolean useSmoothAcceptanceRatio = false;
+		boolean useSmoothAcceptanceRatio = true;
 		double temperature = 1.0;
-		long fullEvaluationCount = 1000;
+		long fullEvaluationCount = 0; // TODO make an option -- 1000;
 		double evaluationTestThreshold = MarkovChain.EVALUATION_TEST_THRESHOLD;
 		int minOperatorCountForFullEvaluation = 1;
 
