@@ -5,13 +5,16 @@ library(EvidenceSynthesis)
 # Simulate large balanced population. Should have normally distributed likelihood:
 set.seed(1)
 trueHazardRatio <- 0.5
-population <- simulatePopulations(settings = createSimulationSettings(nSites = 1,
-                                                                      n = 10000,
-                                                                      treatedFraction = 0.5,
-                                                                      hazardRatio = trueHazardRatio))[[1]]
+population <- simulatePopulations(settings = createSimulationSettings(
+  nSites = 1,
+  n = 10000,
+  treatedFraction = 0.5,
+  hazardRatio = trueHazardRatio
+))[[1]]
 cyclopsData <- Cyclops::createCyclopsData(Surv(time, y) ~ x + strata(stratumId),
-                                          data = population,
-                                          modelType = "cox")
+  data = population,
+  modelType = "cox"
+)
 cyclopsFit <- Cyclops::fitCyclopsModel(cyclopsData)
 x <- log(seq(0.1, 10, length.out = 100))
 ll <- Cyclops::getCyclopsProfileLogLikelihood(cyclopsFit, "x", x)$value
@@ -23,7 +26,7 @@ test_that("Normal approximation", {
   approxLl <- dnorm(x, mean = params$logRr, sd = params$seLogRr, log = TRUE)
   approxLl <- approxLl - max(approxLl)
   expect_equal(ll, approxLl, tolerance = 0.1)
-  
+
   ci <- computeConfidenceInterval(params)
   expect_lt(ci$lb, trueHazardRatio)
   expect_gt(ci$ub, trueHazardRatio)
@@ -34,7 +37,7 @@ test_that("Skew normal approximation", {
   approxLl <- skewNormal(x, mu = params$mu, sigma = params$sigma, alpha = params$alpha)
   approxLl <- approxLl - max(approxLl)
   expect_equal(ll, approxLl, tolerance = 0.1)
-  
+
   ci <- computeConfidenceInterval(params)
   expect_lt(ci$lb, trueHazardRatio)
   expect_gt(ci$ub, trueHazardRatio)
@@ -45,7 +48,7 @@ test_that("Custom approximation", {
   approxLl <- customFunction(x, mu = params$mu, sigma = params$sigma, gamma = params$gamma)
   approxLl <- approxLl - max(approxLl)
   expect_equal(ll, approxLl, tolerance = 0.1)
-  
+
   ci <- computeConfidenceInterval(params)
   expect_lt(ci$lb, trueHazardRatio)
   expect_gt(ci$ub, trueHazardRatio)
@@ -59,7 +62,7 @@ test_that("Grid approximation", {
   ll <- ll - max(ll)
 
   expect_equal(ll, approxLl, tolerance = 0.01, check.attributes = FALSE)
-  
+
   ci <- computeConfidenceInterval(approxLl)
   expect_lt(ci$lb, trueHazardRatio)
   expect_gt(ci$ub, trueHazardRatio)
